@@ -216,7 +216,7 @@ def groups_gen(isa_yaml, grp_yaml, attr_yaml, work_dir, probeinst, logging=False
 def csr_probe_function(isa_yaml, attr_yaml,probeinst, logging=False):
     bsvstr = ''
     bsvstr += '''
-  function Bit#(XLEN) fn_probe_csr (Bit#(12) csr_addr);
+  function Bit#(`xlen) fn_probe_csr (Bit#(12) csr_addr);
     case (csr_addr)
 '''
     if logging:
